# Generated by ariadne-codegen
# Source: openhexa/graphql/queries.graphql

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWebappBySlug(BaseModel):
    webapp: Optional["GetWebappBySlugWebapp"]


class GetWebappBySlugWebapp(BaseModel):
    id: Any
    name: str
    description: Optional[str]
    url: str
    icon: Optional[str]
    is_favorite: bool = Field(alias="isFavorite")
    created_by: "GetWebappBySlugWebappCreatedBy" = Field(alias="createdBy")
    workspace: "GetWebappBySlugWebappWorkspace"
    permissions: "GetWebappBySlugWebappPermissions"


class GetWebappBySlugWebappCreatedBy(BaseModel):
    id: Any
    display_name: str = Field(alias="displayName")
    email: str


class GetWebappBySlugWebappWorkspace(BaseModel):
    slug: str
    name: str


class GetWebappBySlugWebappPermissions(BaseModel):
    update: bool
    delete: bool


GetWebappBySlug.model_rebuild()
GetWebappBySlugWebapp.model_rebuild()
